==> qtkeychain_0.1.0-3.tar.gz: qtkeychain-0.1.0/translations/qtkeychain_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>QKeychain::ReadPasswordJobPrivate</name>
    <message>
        <location filename="../keychain_dbus.cpp" line="176"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="190"/>
        <source>D-Bus is not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="267"/>
        <source>No keychain service available</source>
        <translation>Kein Schlüsselbund-Dienst verfügbar</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="269"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Konnte Brieftasche nicht öffnen: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="315"/>
        <source>Access to keychain denied</source>
        <translation>Zugriff auf Schlüsselbund verweigert</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="336"/>
        <source>Could not determine data type: %1; %2</source>
        <translation>Datentyp kann nicht ermittelt werden: %1: %2</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="354"/>
        <source>Unsupported entry type &apos;Map&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="357"/>
        <source>Unknown kwallet entry type &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="372"/>
        <source>Could not read password: %1; %2</source>
        <translation>Passwort konnte nicht ausgelesen werden: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="76"/>
        <source>Password not found</source>
        <translation>Passwort nicht gefunden</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="345"/>
        <location filename="../keychain_win.cpp" line="27"/>
        <source>Entry not found</source>
        <translation>Eintrag nicht gefunden</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="44"/>
        <source>Could not decrypt data</source>
        <translation>Kann Daten nicht entschlüsseln</translation>
    </message>
</context>
<context>
    <name>QKeychain::WritePasswordJobPrivate</name>
    <message>
        <location filename="../keychain_dbus.cpp" line="393"/>
        <location filename="../keychain_dbus.cpp" line="401"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="416"/>
        <source>D-Bus is not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="457"/>
        <location filename="../keychain_dbus.cpp" line="533"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Konnte Brieftasche nicht öffnen: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="511"/>
        <source>Access to keychain denied</source>
        <translation>Zugriff auf Schlüsselbund verweigert</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="64"/>
        <source>Could not delete encrypted data from settings: access error</source>
        <translation>Kann verschlüsselte Daten nicht aus den Einstellungen entfernen: Zugriffsfehler</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="65"/>
        <source>Could not delete encrypted data from settings: format error</source>
        <translation>Kann verschlüsselte Daten nicht aus den Einstellungen entfernen: Formatfehler</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="85"/>
        <source>Encryption failed</source>
        <translation>Verschlüsselung fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="100"/>
        <source>Could not store encrypted data in settings: access error</source>
        <translation>Kann verschlüsselte Daten nicht in den Einstellungen speichern: Zugriffsfehler</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="101"/>
        <source>Could not store encrypted data in settings: format error</source>
        <translation>Kann verschlüsselte Daten nicht in den Einstellungen speichern: Formatfehler</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../keychain_dbus.cpp" line="212"/>
        <source>Access to keychain denied</source>
        <translation>Zugriff auf Schlüsselbund verweigert</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="214"/>
        <source>No keyring daemon</source>
        <translation>Kein Schlüsselbund-Dienst </translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="216"/>
        <source>Already unlocked</source>
        <translation>Bereits entsperrt</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="218"/>
        <source>No such keyring</source>
        <translation>Kein solcher Schlüsselbund</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="220"/>
        <source>Bad arguments</source>
        <translation>Ungültige Argumente</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="222"/>
        <source>I/O error</source>
        <translation>Ein-/Ausgabe-Fehler</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="224"/>
        <source>Cancelled</source>
        <translation>Abgebrochen</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="226"/>
        <source>Keyring already exists</source>
        <translation>Schlüsselbund existiert bereits</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="228"/>
        <source>No match</source>
        <translation>Kein Treffer</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="233"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="31"/>
        <location filename="../keychain_mac.cpp" line="33"/>
        <source>%1 (OSStatus %2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qtkeychain_0.3.0.orig.tar.gz: qtkeychain-0.3.0/translations/qtkeychain_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>QKeychain::ReadPasswordJobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="53"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="67"/>
        <source>D-Bus is not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="144"/>
        <source>No keychain service available</source>
        <translation>Kein Schlüsselbund-Dienst verfügbar</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="146"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Konnte Brieftasche nicht öffnen: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="192"/>
        <source>Access to keychain denied</source>
        <translation>Zugriff auf Schlüsselbund verweigert</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="213"/>
        <source>Could not determine data type: %1; %2</source>
        <translation>Datentyp kann nicht ermittelt werden: %1: %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="231"/>
        <source>Unsupported entry type &apos;Map&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="234"/>
        <source>Unknown kwallet entry type &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="249"/>
        <source>Could not read password: %1; %2</source>
        <translation>Passwort konnte nicht ausgelesen werden: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="76"/>
        <source>Password not found</source>
        <translation>Passwort nicht gefunden</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="222"/>
        <location filename="../keychain_win.cpp" line="27"/>
        <source>Entry not found</source>
        <translation>Eintrag nicht gefunden</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="44"/>
        <source>Could not decrypt data</source>
        <translation>Kann Daten nicht entschlüsseln</translation>
    </message>
</context>
<context>
    <name>QKeychain::WritePasswordJobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="270"/>
        <location filename="../keychain_unix.cpp" line="278"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="293"/>
        <source>D-Bus is not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="334"/>
        <location filename="../keychain_unix.cpp" line="410"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Konnte Brieftasche nicht öffnen: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="388"/>
        <source>Access to keychain denied</source>
        <translation>Zugriff auf Schlüsselbund verweigert</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="64"/>
        <source>Could not delete encrypted data from settings: access error</source>
        <translation>Kann verschlüsselte Daten nicht aus den Einstellungen entfernen: Zugriffsfehler</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="65"/>
        <source>Could not delete encrypted data from settings: format error</source>
        <translation>Kann verschlüsselte Daten nicht aus den Einstellungen entfernen: Formatfehler</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="85"/>
        <source>Encryption failed</source>
        <translation>Verschlüsselung fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="100"/>
        <source>Could not store encrypted data in settings: access error</source>
        <translation>Kann verschlüsselte Daten nicht in den Einstellungen speichern: Zugriffsfehler</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="101"/>
        <source>Could not store encrypted data in settings: format error</source>
        <translation>Kann verschlüsselte Daten nicht in den Einstellungen speichern: Formatfehler</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../keychain_unix.cpp" line="89"/>
        <source>Access to keychain denied</source>
        <translation>Zugriff auf Schlüsselbund verweigert</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="91"/>
        <source>No keyring daemon</source>
        <translation>Kein Schlüsselbund-Dienst </translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="93"/>
        <source>Already unlocked</source>
        <translation>Bereits entsperrt</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="95"/>
        <source>No such keyring</source>
        <translation>Kein solcher Schlüsselbund</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="97"/>
        <source>Bad arguments</source>
        <translation>Ungültige Argumente</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="99"/>
        <source>I/O error</source>
        <translation>Ein-/Ausgabe-Fehler</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="101"/>
        <source>Cancelled</source>
        <translation>Abgebrochen</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="103"/>
        <source>Keyring already exists</source>
        <translation>Schlüsselbund existiert bereits</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="105"/>
        <source>No match</source>
        <translation>Kein Treffer</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="110"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="31"/>
        <location filename="../keychain_mac.cpp" line="33"/>
        <source>%1 (OSStatus %2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
